@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
-import enum
+from enum import Enum
 
 
-class IntervalLevel(enum.Enum):
+class IntervalLevel(Enum):
     LEVEL_TICK = 'tick'
     LEVEL_1MIN = '1m'
     LEVEL_5MIN = '5m'
@@ -97,7 +97,7 @@ class IntervalLevel(enum.Enum):
         return NotImplemented
 
 
-class AdjustType(enum.Enum):
+class AdjustType(Enum):
     # 这里用拼音，因为英文不直观 split-adjusted？wtf?
     # 不复权
     bfq = 'bfq'
@@ -107,8 +107,79 @@ class AdjustType(enum.Enum):
     hfq = 'hfq'
 
 
-from . import zvt_context
-from .schema import Mixin, NormalMixin, EntityMixin, NormalEntityMixin, PortfolioStock, Portfolio, PortfolioStockHistory
+class ActorType(Enum):
+    # 个人
+    individual = 'individual'
+    # 公募基金
+    raised_fund = 'raised_fund'
+    # 社保
+    social_security = 'social_security'
+    # 保险
+    insurance = 'insurance'
+    # 外资
+    qfii = 'qfii'
+    # 信托
+    trust = 'trust'
+    # 券商
+    broker = 'broker'
+    # 私募
+    private_equity = 'private_equity'
+    # 公司(可能包括私募)
+    corporation = 'corporation'
 
-__all__ = ['IntervalLevel', 'Mixin', 'NormalMixin', 'EntityMixin', 'NormalEntityMixin', 'zvt_context', 'AdjustType',
+
+class TradableType(Enum):
+    # A股(中国)
+    stock = 'stock'
+    # 美股
+    stockus = 'stockus'
+    # 港股
+    stockhk = 'stockhk'
+    # 期货(中国)
+    future = 'future'
+    # 数字货币
+    coin = 'coin'
+    # 期权
+    option = 'option'
+    # 基金
+    fund = 'fund'
+
+
+class Exchange(Enum):
+    # 上证交易所
+    sh = 'sh'
+    # 深证交易所
+    sz = 'sz'
+
+    # 对于中国的非交易所的 标的
+    cn = 'cn'
+
+    # 纳斯达克
+    nasdaq = 'nasdaq'
+
+    # 纽交所
+    nyse = 'nyse'
+
+    # 港交所
+    hk = 'hk'
+
+    # 数字货币
+    binance = 'binance'
+    huobipro = 'huobipro'
+
+    # 上海期货交易所
+    shfe = 'shfe'
+    # 大连商品交易所
+    dce = "dce"
+    # 郑州商品交易所
+    czce = 'czce'
+    # 中国金融期货交易所
+    cffex = 'cffex'
+
+
+from . import zvt_context
+from .schema import Mixin, NormalMixin, TradableEntity, NormalEntityMixin, PortfolioStock, Portfolio, \
+    PortfolioStockHistory
+
+__all__ = ['IntervalLevel', 'Mixin', 'NormalMixin', 'TradableEntity', 'NormalEntityMixin', 'zvt_context', 'AdjustType',
            'Portfolio', 'PortfolioStock', 'PortfolioStockHistory']
