@@ -13,7 +13,7 @@ from sqlalchemy.orm import Query
 from sqlalchemy.orm import sessionmaker, Session
 
 from zvt import zvt_env
-from zvt.contract import IntervalLevel, EntityMixin
+from zvt.contract import IntervalLevel, TradableEntity
 from zvt.contract import Mixin
 from zvt.contract import zvt_context
 from zvt.utils.pd_utils import pd_is_not_null, index_df
@@ -190,7 +190,7 @@ def get_entity_schema(entity_type: str) -> object:
     :return:
     :rtype:
     """
-    return zvt_context.zvt_entity_schema_map[entity_type]
+    return zvt_context.tradable_schema_map[entity_type]
 
 
 def get_schema_by_name(name: str) -> DeclarativeMeta:
@@ -261,7 +261,19 @@ def del_data(data_schema: Type[Mixin], filters: List = None, provider=None):
     session.commit()
 
 
-def get_data(data_schema,
+def get_one(data_schema, id: str, provider: str = None, session: Session = None):
+    if 'providers' not in data_schema.__dict__:
+        logger.error("no provider registered for: {}", data_schema)
+    if not provider:
+        provider = data_schema.providers[0]
+
+    if not session:
+        session = get_db_session(provider=provider, data_schema=data_schema)
+
+    return session.query(data_schema).get(id)
+
+
+def get_data(data_schema: Mixin,
              ids: List[str] = None,
              entity_ids: List[str] = None,
              entity_id: str = None,
@@ -280,9 +292,10 @@ def get_data(data_schema,
              limit: int = None,
              index: Union[str, list] = None,
              time_field: str = 'timestamp'):
-    assert data_schema is not None
-    assert provider is not None
-    assert provider in zvt_context.providers
+    if 'providers' not in data_schema.__dict__:
+        logger.error("no provider registered for: {}", data_schema)
+    if not provider:
+        provider = data_schema.providers[0]
 
     if not session:
         session = get_db_session(provider=provider, data_schema=data_schema)
@@ -363,7 +376,7 @@ def get_data_count(data_schema, filters=None, session=None):
         for filter in filters:
             query = query.filter(filter)
 
-    count_q = query.statement.with_only_columns([func.count()]).order_by(None)
+    count_q = query.statement.with_only_columns([func.count(data_schema.id)]).order_by(None)
     count = session.execute(count_q).scalar()
     return count
 
@@ -407,7 +420,7 @@ def df_to_db(df: pd.DataFrame,
              provider: str,
              force_update: bool = False,
              sub_size: int = 5000,
-             drop_duplicates: bool = False) -> object:
+             drop_duplicates: bool = True) -> object:
     """
     FIXME:improve
     store the df to db
@@ -458,9 +471,9 @@ def df_to_db(df: pd.DataFrame,
             session = get_db_session(provider=provider, data_schema=data_schema)
             ids = df_current["id"].tolist()
             if len(ids) == 1:
-                sql = f'delete from {data_schema.__tablename__} where id = "{ids[0]}"'
+                sql = f'delete from `{data_schema.__tablename__}` where id = "{ids[0]}"'
             else:
-                sql = f'delete from {data_schema.__tablename__} where id in {tuple(ids)}'
+                sql = f'delete from `{data_schema.__tablename__}` where id in {tuple(ids)}'
 
             session.execute(sql)
             session.commit()
@@ -479,7 +492,7 @@ def df_to_db(df: pd.DataFrame,
 
 
 def get_entities(
-        entity_schema: EntityMixin = None,
+        entity_schema: TradableEntity = None,
         entity_type: str = None,
         exchanges: List[str] = None,
         ids: List[str] = None,
@@ -499,7 +512,7 @@ def get_entities(
         limit: int = None,
         index: Union[str, list] = 'code') -> object:
     if not entity_schema:
-        entity_schema = zvt_context.entity_schema_map[entity_type]
+        entity_schema = zvt_context.tradable_schema_map[entity_type]
 
     if not provider:
         provider = entity_schema.providers[0]
@@ -519,7 +532,7 @@ def get_entities(
                     filters=filters, session=session, order=order, limit=limit, index=index)
 
 
-def get_entity_ids(entity_type='stock', entity_schema: EntityMixin = None, exchanges=None, codes=None, provider=None,
+def get_entity_ids(entity_type='stock', entity_schema: TradableEntity = None, exchanges=None, codes=None, provider=None,
                    filters=None):
     df = get_entities(entity_type=entity_type, entity_schema=entity_schema, exchanges=exchanges, codes=codes,
                       provider=provider, filters=filters)
