@@ -11,6 +11,6 @@ class Stock1dZenFactor(Stock1dZenFactorBase, ZenFactorCommon):
     __tablename__ = 'stock_1d_zen_factor'
 
 
-register_schema(providers=['zvt'], db_name='stock_1d_zen_factor', schema_base=Stock1dZenFactorBase)
+register_schema(providers=['zvt'], db_name='stock_1d_zen_factor', schema_base=Stock1dZenFactorBase, entity_type='stock')
 # the __all__ is generated
-__all__ = ['Stock1dZenFactor']
+__all__ = ['Stock1dZenFactor']
\ No newline at end of file
